import { select, tsv, geoPath, 
        geoNaturalEarth1, zoom, event,
       scaleOrdinal, schemeSpectral} from 'd3';
import {feature} from 'topojson';
import {loadAndProcessData} from './loadAndProcess.js'
import { colorLegend } from './colorLegend.js'
import { colorLegend } from './choroplethMap.js'

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g');

const colorLegendG = svg.append('g')
		.attr('transform', `translate(40, ${height -200})`)

const colorScale = scaleOrdinal(schemeSpectral[7]);

const colorValue = d => d.properties.economy;

let selectedColorValue;
let features;

const onClick = d => {
	selectedColorValue = d;
  render();
};

loadAndProcessData().then(countries => {
  		features = countries.features;
  		render();
  		});

const render = () => {
	colorScale
        		.domain(features.map(colorValue))
  					.domain(colorScale.domain().sort().reverse())
  					.range(schemeSpectral[colorScale.domain().length]);
  
  		colorLegendG.call(colorLegend, {
  		colorScale,
  		circleR : 10,
  		spacing: 30,
   		textOff: 30,
      BgWidth: 250,
      onClick,
      selectedColorValue
      });
	 
  		
};




	









